@@ -1,14 +1,20 @@
 import logging
 import os
 import time
+import aiohttp
+import ssl
+import certifi
 from urllib.parse import urlencode, urlparse
 
 from requests import Request, Session, status_codes
 
 from Tea.exceptions import TeaException, RequiredArgumentException
 from Tea.model import TeaModel
+from Tea.request import TeaRequest
 from Tea.response import TeaResponse
 
+from typing import Dict, Any, Optional
+
 DEFAULT_CONNECT_TIMEOUT = 5000
 DEFAULT_READ_TIMEOUT = 10000
 
@@ -23,21 +29,19 @@ class TeaCore:
     def _prepare_http_debug(request, symbol):
         base = ''
         for key, value in request.headers.items():
-            base += '\n%s %s : %s' % (symbol, key, value)
+            base += f'\n{symbol} {key} : {value}'
         return base
 
     @staticmethod
     def _do_http_debug(request, response):
         # logger the request
         url = urlparse(request.url)
-        request_base = '\n> %s %s HTTP/1.1' % (request.method.upper(), url.path + url.query)
+        request_base = f'\n> {request.method.upper()} {url.path + url.query} HTTP/1.1'
         logger.debug(request_base + TeaCore._prepare_http_debug(request, '>'))
 
         # logger the response
-        response_base = '\n< HTTP/1.1 %s %s' % (
-            response.status_code,
-            status_codes._codes.get(response.status_code)[0].upper()
-        )
+        response_base = f'\n< HTTP/1.1 {response.status_code}' \
+                        f' {status_codes._codes.get(response.status_code)[0].upper()}'
         logger.debug(response_base + TeaCore._prepare_http_debug(response, '<'))
 
     @staticmethod
@@ -47,7 +51,7 @@ class TeaCore:
             raise RequiredArgumentException('endpoint')
         else:
             host = host.rstrip('/')
-        protocol = '%s://' % request.protocol.lower()
+        protocol = f'{request.protocol.lower()}://'
         pathname = request.pathname
 
         if host.startswith(('http://', 'https://')):
@@ -56,7 +60,7 @@ class TeaCore:
         if request.port == 80:
             port = ''
         else:
-            port = ':%s' % request.port
+            port = f':{request.port}'
 
         url = protocol + host + port + pathname
 
@@ -76,7 +80,62 @@ class TeaCore:
         return url.rstrip("?&")
 
     @staticmethod
-    def do_action(request, runtime_option=None):
+    async def async_do_action(
+        request: TeaRequest,
+        runtime_option=None
+    ) -> TeaResponse:
+        runtime_option = runtime_option or {}
+
+        url = TeaCore.compose_url(request)
+        verify = not runtime_option.get('ignoreSSL', False)
+        connect_timeout = runtime_option.get('connectTimeout')
+        connect_timeout = connect_timeout if connect_timeout else DEFAULT_CONNECT_TIMEOUT
+
+        read_timeout = runtime_option.get('readTimeout')
+        read_timeout = read_timeout if read_timeout else DEFAULT_READ_TIMEOUT
+
+        connect_timeout, read_timeout = (int(connect_timeout) / 1000, int(read_timeout) / 1000)
+
+        proxy = None
+        if request.protocol.upper() == 'HTTP':
+            proxy = runtime_option.get('httpProxy')
+            if not proxy:
+                proxy = os.environ.get('HTTP_PROXY') or os.environ.get('http_proxy')
+
+        connector = None
+        ca_cert = certifi.where()
+        if ca_cert and request.protocol.upper() == 'HTTPS':
+            ssl_context = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
+            ssl_context.load_verify_locations(ca_cert)
+            connector = aiohttp.TCPConnector(
+                ssl=ssl_context,
+            )
+        timeout = aiohttp.ClientTimeout(
+            sock_read=read_timeout,
+            sock_connect=connect_timeout
+        )
+        async with aiohttp.ClientSession(
+            connector=connector
+        ) as s:
+            async with s.request(request.method, url,
+                                 data=request.body,
+                                 headers=request.headers,
+                                 verify_ssl=verify,
+                                 proxy=proxy,
+                                 timeout=timeout) as response:
+                tea_resp = TeaResponse()
+                tea_resp.body = await response.read()
+                tea_resp.headers = response.headers
+                tea_resp.status_code = response.status
+                tea_resp.status_message = response.reason
+                tea_resp.response = response
+        return tea_resp
+
+    @staticmethod
+    def do_action(
+        request: TeaRequest,
+        runtime_option=None
+    ) -> TeaResponse:
         url = TeaCore.compose_url(request)
 
         runtime_option = runtime_option or {}
@@ -122,14 +181,21 @@ class TeaCore:
             debug = runtime_option.get('debug') or os.getenv('DEBUG')
             if debug and debug.lower() == 'sdk':
                 TeaCore._do_http_debug(req, resp)
-            return TeaResponse(resp)
+
+            response = TeaResponse()
+            response.status_message = resp.reason
+            response.status_code = resp.status_code
+            response.headers = {k.lower(): v for k, v in resp.headers.items()}
+            response.body = resp.content
+            response.response = resp
+            return response
 
     @staticmethod
-    def get_response_body(resp):
+    def get_response_body(resp) -> str:
         return resp.content.decode("utf-8")
 
     @staticmethod
-    def allow_retry(dic, retry_times, now=None):
+    def allow_retry(dic, retry_times, now=None) -> bool:
         if dic is None or not dic.__contains__("maxAttempts"):
             return False
         else:
@@ -138,7 +204,7 @@ class TeaCore:
         return retry >= retry_times
 
     @staticmethod
-    def get_backoff_time(dic, retry_times):
+    def get_backoff_time(dic, retry_times) -> int:
         default_back_off_time = 0
         if dic is None or not dic.get("policy") or dic.get("policy") == "no":
             return default_back_off_time
@@ -159,7 +225,7 @@ class TeaCore:
         time.sleep(t)
 
     @staticmethod
-    def is_retryable(ex):
+    def is_retryable(ex) -> bool:
         return isinstance(ex, TeaException)
 
     @staticmethod
@@ -167,25 +233,27 @@ class TeaCore:
         return body
 
     @staticmethod
-    def merge(*dic_list):
+    def merge(*dic_list) -> dict:
         dic_result = {}
         for item in dic_list:
             if isinstance(item, dict):
-                if item is not None:
-                    dic_result.update(item)
+                dic_result.update(item)
             elif isinstance(item, TeaModel):
                 dic_result.update(item.to_map())
         return dic_result
 
     @staticmethod
-    def to_map(model):
+    def to_map(model: Optional[TeaModel]) -> Dict[str, Any]:
         if isinstance(model, TeaModel):
             return model.to_map()
         else:
-            return {}
+            return dict()
 
     @staticmethod
-    def from_map(model, dic):
+    def from_map(
+            model: TeaModel,
+            dic: Dict[str, Any]
+    ) -> TeaModel:
         if isinstance(model, TeaModel):
             return model.from_map(dic)
         else:
